==> openshift-model-operator-5.12.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/ClientTLSBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ClientTLSBuilder extends io.fabric8.openshift.api.model.operator.v1.ClientTLSFluentImpl<io.fabric8.openshift.api.model.operator.v1.ClientTLSBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.ClientTLS,io.fabric8.openshift.api.model.operator.v1.ClientTLSBuilder>{
  public ClientTLSBuilder() {
    this(false);
  }
  public ClientTLSBuilder(java.lang.Boolean validationEnabled) {
    this(new ClientTLS(), validationEnabled);
  }
  public ClientTLSBuilder(io.fabric8.openshift.api.model.operator.v1.ClientTLSFluent<?> fluent) {
    this(fluent, false);
  }
  public ClientTLSBuilder(io.fabric8.openshift.api.model.operator.v1.ClientTLSFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ClientTLS(), validationEnabled);
  }
  public ClientTLSBuilder(io.fabric8.openshift.api.model.operator.v1.ClientTLSFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.ClientTLS instance) {
    this(fluent, instance, false);
  }
  public ClientTLSBuilder(io.fabric8.openshift.api.model.operator.v1.ClientTLSFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.ClientTLS instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAllowedSubjectPatterns(instance.getAllowedSubjectPatterns()); 
    fluent.withClientCA(instance.getClientCA()); 
    fluent.withClientCertificatePolicy(instance.getClientCertificatePolicy()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ClientTLSBuilder(io.fabric8.openshift.api.model.operator.v1.ClientTLS instance) {
    this(instance,false);
  }
  public ClientTLSBuilder(io.fabric8.openshift.api.model.operator.v1.ClientTLS instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAllowedSubjectPatterns(instance.getAllowedSubjectPatterns()); 
    this.withClientCA(instance.getClientCA()); 
    this.withClientCertificatePolicy(instance.getClientCertificatePolicy()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.ClientTLSFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.ClientTLS build() {
    ClientTLS buildable = new ClientTLS(fluent.getAllowedSubjectPatterns(),fluent.getClientCA(),fluent.getClientCertificatePolicy());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClientTLSBuilder that = (ClientTLSBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-6.2.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/ClientTLSBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClientTLSBuilder extends ClientTLSFluentImpl<ClientTLSBuilder> implements VisitableBuilder<ClientTLS,ClientTLSBuilder>{
  public ClientTLSBuilder() {
    this(false);
  }
  public ClientTLSBuilder(Boolean validationEnabled) {
    this(new ClientTLS(), validationEnabled);
  }
  public ClientTLSBuilder(ClientTLSFluent<?> fluent) {
    this(fluent, false);
  }
  public ClientTLSBuilder(ClientTLSFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClientTLS(), validationEnabled);
  }
  public ClientTLSBuilder(ClientTLSFluent<?> fluent,ClientTLS instance) {
    this(fluent, instance, false);
  }
  public ClientTLSBuilder(ClientTLSFluent<?> fluent,ClientTLS instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAllowedSubjectPatterns(instance.getAllowedSubjectPatterns()); 
    fluent.withClientCA(instance.getClientCA()); 
    fluent.withClientCertificatePolicy(instance.getClientCertificatePolicy()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ClientTLSBuilder(ClientTLS instance) {
    this(instance,false);
  }
  public ClientTLSBuilder(ClientTLS instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAllowedSubjectPatterns(instance.getAllowedSubjectPatterns()); 
    this.withClientCA(instance.getClientCA()); 
    this.withClientCertificatePolicy(instance.getClientCertificatePolicy()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ClientTLSFluent<?> fluent;
  Boolean validationEnabled;
  public ClientTLS build() {
    ClientTLS buildable = new ClientTLS(fluent.getAllowedSubjectPatterns(),fluent.getClientCA(),fluent.getClientCertificatePolicy());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
